
.. py:currentmodule:: pythreejs

InterleavedBuffer
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: InterleavedBuffer(array=None, stride=0, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/core/InterleavedBuffer


    .. py:attribute:: array

        .. sourcecode:: python

            WebGLDataUnion().tag(sync=True)

    .. py:attribute:: stride

        .. sourcecode:: python

            CInt(0, allow_none=False).tag(sync=True)

    .. py:attribute:: dynamic

        .. sourcecode:: python

            Bool(False, allow_none=False).tag(sync=True)

    .. py:attribute:: version

        .. sourcecode:: python

            CInt(0, allow_none=False).tag(sync=True)

    .. py:attribute:: needsUpdate

        .. sourcecode:: python

            Bool(False, allow_none=False).tag(sync=True)

